# Find Distance between Two Points
The package finds distance between two given points. The points may lie on geodesic place or euclidean place.

### Distance between Two Points on Geodesic Plane
The script uses [haversine formula](https://www.movable-type.co.uk/scripts/latlong.html)

### Distance between Two Points on Euclidean Plane (2-D)
It uses euclidean distance formula

### Required Libraries
1. math